{% load form_builder_tags %}{% spaceless %}
    {% if form_field|stringformat:"s" == form_field %}
        {% render_widget form form_field  %}
    {% else %}
        <div class="row">
            {% for form_field in form_field %}
                <div class="col">
                    {% include "djangocms_form_builder/bootstrap5/render/field.html" with form=form form_field=form_field %}
                </div>
            {% endfor %}
        </div>
    {% endif %}
{% endspaceless %}
