{% if widget.wrap_label %}<input style="display: none;" type="{{ widget.type }}" class="btn-check" name="{{ widget.name }}"{% if widget.value != None %} value="{{ widget.value|stringformat:'s' }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}><label{% if widget.attrs.id %} title="{{ widget.label }}" class="btn btn-grp btn-{{ widget.value|default:"no-selection" }}" style="--fe-value: {{ widget.value|stringformat:'s' }};" for="{{ widget.attrs.id }}"{% endif %}>{% endif %}{% if widget.wrap_label %} {{ widget.label }}</label>{% endif %}
